@@ -16,7 +16,7 @@ extern "C" {
 
 #define AVIF_VERSION_MAJOR 0
 #define AVIF_VERSION_MINOR 7
-#define AVIF_VERSION_PATCH 1
+#define AVIF_VERSION_PATCH 3
 #define AVIF_VERSION (AVIF_VERSION_MAJOR * 10000) + (AVIF_VERSION_MINOR * 100) + AVIF_VERSION_PATCH
 
 typedef int avifBool;
@@ -163,27 +163,18 @@ typedef enum avifNclxColourPrimaries
     AVIF_NCLX_COLOUR_PRIMARIES_UNKNOWN = 0,
 
     AVIF_NCLX_COLOUR_PRIMARIES_BT709 = 1,
-    AVIF_NCLX_COLOUR_PRIMARIES_BT1361_0 = 1,
-    AVIF_NCLX_COLOUR_PRIMARIES_IEC61966_2_1 = 1,
-    AVIF_NCLX_COLOUR_PRIMARIES_SRGB = 1,
-    AVIF_NCLX_COLOUR_PRIMARIES_SYCC = 1,
     AVIF_NCLX_COLOUR_PRIMARIES_IEC61966_2_4 = 1,
     AVIF_NCLX_COLOUR_PRIMARIES_UNSPECIFIED = 2,
-    AVIF_NCLX_COLOUR_PRIMARIES_BT470_6M = 4,
-    AVIF_NCLX_COLOUR_PRIMARIES_BT601_7_625 = 5,
-    AVIF_NCLX_COLOUR_PRIMARIES_BT470_6G = 5,
-    AVIF_NCLX_COLOUR_PRIMARIES_BT601_7_525 = 6,
-    AVIF_NCLX_COLOUR_PRIMARIES_BT1358 = 6,
-    AVIF_NCLX_COLOUR_PRIMARIES_ST240 = 7,
+    AVIF_NCLX_COLOUR_PRIMARIES_BT470M = 4,
+    AVIF_NCLX_COLOUR_PRIMARIES_BT470BG = 5,
+    AVIF_NCLX_COLOUR_PRIMARIES_BT601 = 6,
+    AVIF_NCLX_COLOUR_PRIMARIES_SMPTE240 = 7,
     AVIF_NCLX_COLOUR_PRIMARIES_GENERIC_FILM = 8,
     AVIF_NCLX_COLOUR_PRIMARIES_BT2020 = 9,
-    AVIF_NCLX_COLOUR_PRIMARIES_BT2100 = 9,
     AVIF_NCLX_COLOUR_PRIMARIES_XYZ = 10,
-    AVIF_NCLX_COLOUR_PRIMARIES_ST428 = 10,
-    AVIF_NCLX_COLOUR_PRIMARIES_RP431_2 = 11,
-    AVIF_NCLX_COLOUR_PRIMARIES_EG432_1 = 12,
-    AVIF_NCLX_COLOUR_PRIMARIES_P3 = 12,
-    AVIF_NCLX_COLOUR_PRIMARIES_EBU3213E = 22
+    AVIF_NCLX_COLOUR_PRIMARIES_SMPTE431 = 11,
+    AVIF_NCLX_COLOUR_PRIMARIES_SMPTE432 = 12, // DCI P3
+    AVIF_NCLX_COLOUR_PRIMARIES_EBU3213 = 22
 } avifNclxColourPrimaries;
 
 // outPrimaries: rX, rY, gX, gY, bX, bY, wX, wY
@@ -196,48 +187,37 @@ typedef enum avifNclxTransferCharacteristics
     AVIF_NCLX_TRANSFER_CHARACTERISTICS_UNKNOWN = 0,
 
     AVIF_NCLX_TRANSFER_CHARACTERISTICS_BT709 = 1,
-    AVIF_NCLX_TRANSFER_CHARACTERISTICS_BT1361 = 1,
     AVIF_NCLX_TRANSFER_CHARACTERISTICS_UNSPECIFIED = 2,
-    AVIF_NCLX_TRANSFER_CHARACTERISTICS_GAMMA22 = 4,
-    AVIF_NCLX_TRANSFER_CHARACTERISTICS_GAMMA28 = 5,
+    AVIF_NCLX_TRANSFER_CHARACTERISTICS_BT470M = 4,  // 2.2 gamma
+    AVIF_NCLX_TRANSFER_CHARACTERISTICS_BT470BG = 5, // 2.8 gamma
     AVIF_NCLX_TRANSFER_CHARACTERISTICS_BT601 = 6,
-    AVIF_NCLX_TRANSFER_CHARACTERISTICS_ST240 = 7,
+    AVIF_NCLX_TRANSFER_CHARACTERISTICS_SMPTE240 = 7,
     AVIF_NCLX_TRANSFER_CHARACTERISTICS_LINEAR = 8,
-    AVIF_NCLX_TRANSFER_CHARACTERISTICS_LOG_100_1 = 9,
-    AVIF_NCLX_TRANSFER_CHARACTERISTICS_LOG_100_SQRT = 10,
+    AVIF_NCLX_TRANSFER_CHARACTERISTICS_LOG100 = 9,
+    AVIF_NCLX_TRANSFER_CHARACTERISTICS_LOG100_SQRT10 = 10,
     AVIF_NCLX_TRANSFER_CHARACTERISTICS_IEC61966 = 11,
-    AVIF_NCLX_TRANSFER_CHARACTERISTICS_BT1361_EXTENDED = 12,
-    AVIF_NCLX_TRANSFER_CHARACTERISTICS_61966_2_1 = 13,
+    AVIF_NCLX_TRANSFER_CHARACTERISTICS_BT1361 = 12,
     AVIF_NCLX_TRANSFER_CHARACTERISTICS_SRGB = 13,
-    AVIF_NCLX_TRANSFER_CHARACTERISTICS_SYCC = 13,
     AVIF_NCLX_TRANSFER_CHARACTERISTICS_BT2020_10BIT = 14,
     AVIF_NCLX_TRANSFER_CHARACTERISTICS_BT2020_12BIT = 15,
-    AVIF_NCLX_TRANSFER_CHARACTERISTICS_ST2084 = 16,
-    AVIF_NCLX_TRANSFER_CHARACTERISTICS_BT2100_PQ = 16,
-    AVIF_NCLX_TRANSFER_CHARACTERISTICS_ST428 = 17,
-    AVIF_NCLX_TRANSFER_CHARACTERISTICS_STD_B67 = 18,
-    AVIF_NCLX_TRANSFER_CHARACTERISTICS_BT2100_HLG = 18
+    AVIF_NCLX_TRANSFER_CHARACTERISTICS_SMPTE2084 = 16, // PQ
+    AVIF_NCLX_TRANSFER_CHARACTERISTICS_SMPTE428 = 17,
+    AVIF_NCLX_TRANSFER_CHARACTERISTICS_HLG = 18
 } avifNclxTransferCharacteristics;
 
 typedef enum avifNclxMatrixCoefficients
 {
     AVIF_NCLX_MATRIX_COEFFICIENTS_IDENTITY = 0,
     AVIF_NCLX_MATRIX_COEFFICIENTS_BT709 = 1,
-    AVIF_NCLX_MATRIX_COEFFICIENTS_BT1361_0 = 1,
-    AVIF_NCLX_MATRIX_COEFFICIENTS_SRGB = 1,
-    AVIF_NCLX_MATRIX_COEFFICIENTS_SYCC = 1,
     AVIF_NCLX_MATRIX_COEFFICIENTS_UNSPECIFIED = 2,
-    AVIF_NCLX_MATRIX_COEFFICIENTS_USFC_73682 = 4,
-    AVIF_NCLX_MATRIX_COEFFICIENTS_BT470_6B = 5,
-    AVIF_NCLX_MATRIX_COEFFICIENTS_BT601_7_625 = 5,
-    AVIF_NCLX_MATRIX_COEFFICIENTS_BT601_7_525 = 6,
-    AVIF_NCLX_MATRIX_COEFFICIENTS_BT1700_NTSC = 6,
-    AVIF_NCLX_MATRIX_COEFFICIENTS_ST170 = 6,
-    AVIF_NCLX_MATRIX_COEFFICIENTS_ST240 = 7,
+    AVIF_NCLX_MATRIX_COEFFICIENTS_FCC = 4,
+    AVIF_NCLX_MATRIX_COEFFICIENTS_BT470BG = 5,
+    AVIF_NCLX_MATRIX_COEFFICIENTS_BT601 = 6,
+    AVIF_NCLX_MATRIX_COEFFICIENTS_SMPTE240 = 7,
+    AVIF_NCLX_MATRIX_COEFFICIENTS_YCGCO = 8,
     AVIF_NCLX_MATRIX_COEFFICIENTS_BT2020_NCL = 9,
-    AVIF_NCLX_MATRIX_COEFFICIENTS_BT2100 = 9,
     AVIF_NCLX_MATRIX_COEFFICIENTS_BT2020_CL = 10,
-    AVIF_NCLX_MATRIX_COEFFICIENTS_ST2085 = 11,
+    AVIF_NCLX_MATRIX_COEFFICIENTS_SMPTE2085 = 11,
     AVIF_NCLX_MATRIX_COEFFICIENTS_CHROMA_DERIVED_NCL = 12,
     AVIF_NCLX_MATRIX_COEFFICIENTS_CHROMA_DERIVED_CL = 13,
     AVIF_NCLX_MATRIX_COEFFICIENTS_ICTCP = 14
@@ -443,6 +423,12 @@ int avifFullToLimitedUV(int depth, int v);
 int avifLimitedToFullY(int depth, int v);
 int avifLimitedToFullUV(int depth, int v);
 
+typedef enum avifReformatMode
+{
+    AVIF_REFORMAT_MODE_YUV_COEFFICIENTS = 0, // Normal YUV conversion using coefficients
+    AVIF_REFORMAT_MODE_IDENTITY              // Pack GBR directly into YUV planes (AVIF_NCLX_MATRIX_COEFFICIENTS_IDENTITY)
+} avifReformatMode;
+
 typedef struct avifReformatState
 {
     // YUV coefficients
@@ -464,6 +450,8 @@ typedef struct avifReformatState
     // LUTs for going from YUV limited/full unorm -> full range RGB FP32
     float unormFloatTableY[1 << 12];
     float unormFloatTableUV[1 << 12];
+
+    avifReformatMode mode;
 } avifReformatState;
 avifBool avifPrepareReformatState(avifImage * image, avifRGBImage * rgb, avifReformatState * state);
 
